@@ -278,13 +278,12 @@ Default ProtoSelect metadata.
 """
 
 DEFAULT_DATA_PROTOSELECT = {"prototypes": None,
-                            "prototypes_indices": None,
-                            "prototypes_labels": None}  # type: dict
+                            "prototype_indices": None,
+                            "prototype_labels": None}  # type: dict
 """
 Default ProtoSelect data.
 """
 
-
 # PartialDependence
 DEFAULT_META_PD = {
     "name": None,
@@ -307,3 +306,50 @@ DEFAULT_DATA_PD = {
 """
 Default PartialDependence data.
 """
+
+# PartialDependenceVariance
+DEFAULT_META_PDVARIANCE = {
+    "name": None,
+    "type": ["blackbox"],
+    "explanations": ["global"],
+    "params": {},
+    "version": None
+}  # type: dict
+"""
+Default PartialDependenceVariance metadata.
+"""
+
+DEFAULT_DATA_PDVARIANCE = {
+    "feature_deciles": None,
+    "pd_values": None,
+    "feature_values": None,
+    "feature_names": None,
+    "feature_importance": None,
+    "feature_interaction": None,
+    "conditional_importance": None,
+    "conditional_importance_values": None
+}  # type: dict
+"""
+Default PartialDependenceVariance data.
+"""
+
+# PermutationImportance
+DEFAULT_META_PERMUTATION_IMPORTANCE = {
+    "name": None,
+    "type": ["blackbox"],
+    "explanations": ["global"],
+    "params": {},
+    "version": None
+}  # type: dict
+"""
+Default PermutationImportance metadata.
+"""
+
+DEFAULT_DATA_PERMUTATION_IMPORTANCE = {
+    "feature_names": None,
+    "metric_names": None,
+    "feature_importance": None,
+}  # type: dict
+"""
+Default PermutationImportance data.
+"""
