@@ -3,8 +3,7 @@ The 'alibi.confidence' module includes trust scores.
 """
 
 from .trustscore import TrustScore
-from .model_linearity import LinearityMeasure
-from .model_linearity import linearity_measure
+from .model_linearity import LinearityMeasure, linearity_measure
 
 __all__ = ["linearity_measure",
            "LinearityMeasure",
