@@ -37,9 +37,9 @@ class AnchorBaseBeam:
         Parameters
         ----------
         batch_size
-            See :py:meth:`alibi.explainers.anchor_base.AnchorBaseBeam.anchor_beam` method.
+            See :py:meth:`alibi.explainers.anchors.anchor_base.AnchorBaseBeam.anchor_beam` method.
         coverage_data
-            See :py:meth:`alibi.explainers.anchor_base.AnchorBaseBeam._get_coverage_samples` method.
+            See :py:meth:`alibi.explainers.anchors.anchor_base.AnchorBaseBeam._get_coverage_samples` method.
         """
 
         prealloc_size = batch_size * self.sample_cache_size
@@ -165,7 +165,10 @@ class AnchorBaseBeam:
         -------
         Level used to update upper and lower precision bounds.
         """
-        # TODO: where do magic numbers come from?
+        # The following constants are defined and used in the paper introducing the KL-LUCB bandit algorithm
+        # (http://proceedings.mlr.press/v30/Kaufmann13.html). Specifically, Theorem 1 proves the lower bounds
+        # of these constants to ensure the algorithm is PAC with probability at least 1-delta. Also refer to
+        # section "5. Numerical experiments" where these values are used empirically.
         alpha = 1.1
         k = 405.5
         temp = np.log(k * n_features * (t ** alpha) / delta)
@@ -179,9 +182,9 @@ class AnchorBaseBeam:
         Parameters
         ---------
         coverage_samples
-            See :py:meth:`alibi.explainers.anchor_base.AnchorBaseBeam.anchor_beam` method.
+            See :py:meth:`alibi.explainers.anchors.anchor_base.AnchorBaseBeam.anchor_beam` method.
         samplers
-            See :py:meth:`alibi.explainers.anchor_base.AnchorBaseBeam.__init__` method.
+            See :py:meth:`alibi.explainers.anchors.anchor_base.AnchorBaseBeam.__init__` method.
 
         Returns
         -------
@@ -419,7 +422,7 @@ class AnchorBaseBeam:
     def update_state(self, covered_true: np.ndarray, covered_false: np.ndarray, labels: np.ndarray,
                      samples: Tuple[np.ndarray, float], anchor: tuple) -> Tuple[int, int]:
         """
-        Updates the explainer state (see :py:meth:`alibi.explainers.anchor_base.AnchorBaseBeam.__init__`
+        Updates the explainer state (see :py:meth:`alibi.explainers.anchors.anchor_base.AnchorBaseBeam.__init__`
         for full state definition).
 
         Parameters
@@ -790,8 +793,12 @@ class AnchorBaseBeam:
         # if no result is found, choose highest precision of best result candidate from every round
         if not best_anchor:
             success = False  # indicates the method has not found an anchor
-            logger.warning('Could not find an result satisfying the {} precision constraint. Now returning '
-                           'the best non-eligible result.'.format(desired_confidence))
+            logger.warning(f'Could not find an anchor satisfying the {desired_confidence} precision constraint. '
+                           f'Now returning the best non-eligible result. The desired precision threshold might not be '
+                           f'achieved due to the quantile-based discretisation of the numerical features. The '
+                           f'resolution of the bins may be too large to find an anchor of required precision. '
+                           f'Consider increasing the number of bins in `disc_perc`, but note that for some '
+                           f'numerical distribution (e.g. skewed distribution) it may not help.')
             anchors = []
             for i in range(0, current_size):
                 anchors.extend(best_of_size[i])
