@@ -8,8 +8,9 @@ import numpy as np
 
 from alibi.api.defaults import DEFAULT_DATA_ANCHOR, DEFAULT_META_ANCHOR
 from alibi.api.interfaces import Explainer, Explanation, FitMixin
-from alibi.exceptions import (AlibiPredictorCallException,
-                              AlibiPredictorReturnTypeError)
+from alibi.exceptions import (NotFittedError,
+                              PredictorCallError,
+                              PredictorReturnTypeError)
 from alibi.utils.discretizer import Discretizer
 from alibi.utils.mapping import ohe_to_ord, ord_to_ohe
 from alibi.utils.wrappers import ArgmaxTransformer
@@ -249,7 +250,8 @@ class TabularSampler:
 
     def perturbation(self, anchor: tuple, num_samples: int) -> Tuple[np.ndarray, np.ndarray, float]:
         """
-        Implements functionality described in :py:meth:`alibi.explainers.anchor_tabular.TabularSampler.__call__`.
+        Implements functionality described in
+        :py:meth:`alibi.explainers.anchors.anchor_tabular.TabularSampler.__call__`.
 
         Parameters
         ----------
@@ -288,6 +290,10 @@ class TabularSampler:
             [allowed_rows[feat] for feat in uniq_feat_ids],
             np.intersect1d),
         )
+        if partial_anchor_rows == []:
+            # edge case - if there are no rows at all then `partial_anchor_rows` is the empty list, but it should
+            # be a list of an empty array to not cause an error in calculating coverage (which will be 0)
+            partial_anchor_rows = [np.array([], dtype=int)]
         nb_partial_anchors = np.array([len(n_records) for n_records in
                                        reversed(partial_anchor_rows)])  # reverse required for np.searchsorted later
         coverage = nb_partial_anchors[0] / self.n_records  # since we sorted, the correct coverage is first not last
@@ -329,7 +335,7 @@ class TabularSampler:
         Parameters
         ----------
         allowed_bins
-            See :py:meth:`alibi.explainers.anchor_tabular.TabularSampler.get_feature_index` method.
+            See :py:meth:`alibi.explainers.anchors.anchor_tabular.TabularSampler.get_features_index` method.
         num_samples
             Number of replacement values.
         samples
@@ -381,7 +387,14 @@ class TabularSampler:
         requested_samples = num_samples
         start, n_anchor_feats = 0, len(partial_anchor_rows)
         uniq_feat_ids = list(reversed(uniq_feat_ids))
-        start_idx = np.nonzero(nb_partial_anchors)[0][0]  # skip anchors with no samples in the database
+
+        try:
+            start_idx = np.nonzero(nb_partial_anchors)[0][0]  # skip anchors with no samples in the database
+        except IndexError:
+            # there are no samples in the database, need to break out of the function
+            # and go straight to treating unknown features
+            return
+
         end_idx = np.searchsorted(np.cumsum(nb_partial_anchors), num_samples)
 
         # replace partial anchors with partial anchors drawn from the training dataset
@@ -609,9 +622,9 @@ class AnchorTabular(Explainer, FitMixin):
 
         Raises
         ------
-        :py:class:`alibi.exceptions.AlibiPredictorCallException`
+        :py:class:`alibi.exceptions.PredictorCallError`
             If calling `predictor` fails at runtime.
-        :py:class:`alibi.exceptions.AlibiPredictorReturnTypeError`
+        :py:class:`alibi.exceptions.PredictorReturnTypeError`
             If the return type of `predictor` is not `np.ndarray`.
         """
         super().__init__(meta=copy.deepcopy(DEFAULT_META_ANCHOR))
@@ -646,6 +659,8 @@ class AnchorTabular(Explainer, FitMixin):
         # update metadata
         self.meta['params'].update(seed=seed)
 
+        self._fitted = False
+
     def fit(self,  # type: ignore[override]
             train_data: np.ndarray,
             disc_perc: Tuple[Union[int, float], ...] = (25, 50, 75),
@@ -685,6 +700,8 @@ class AnchorTabular(Explainer, FitMixin):
         # update metadata
         self.meta['params'].update(disc_perc=disc_perc)
 
+        self._fitted = True
+
         return self
 
     def _build_sampling_lookups(self, X: np.ndarray) -> None:
@@ -726,17 +743,40 @@ class AnchorTabular(Explainer, FitMixin):
         X
             Instance to be explained.
         threshold
-            Minimum precision threshold.
+            Minimum anchor precision threshold. The algorithm tries to find an anchor that maximizes the coverage
+            under precision constraint. The precision constraint is formally defined as
+            :math:`P(prec(A) \\ge t) \\ge 1 - \\delta`, where :math:`A` is an anchor, :math:`t` is the `threshold`
+            parameter, :math:`\\delta` is the `delta` parameter, and :math:`prec(\\cdot)` denotes the precision
+            of an anchor. In other words, we are seeking for an anchor having its precision greater or equal than
+            the given `threshold` with a confidence of `(1 - delta)`. A higher value guarantees that the anchors are
+            faithful to the model, but also leads to more computation time. Note that there are cases in which the
+            precision constraint cannot be satisfied due to the quantile-based discretisation of the numerical
+            features. If that is the case, the best (i.e. highest coverage) non-eligible anchor is returned.
         delta
-            Used to compute `beta`.
+            Significance threshold. `1 - delta` represents the confidence threshold for the anchor precision
+            (see `threshold`) and the selection of the best anchor candidate in each iteration (see `tau`).
         tau
-            Margin between lower confidence bound and minimum precision or upper bound.
+            Multi-armed bandit parameter used to select candidate anchors in each iteration. The multi-armed bandit
+            algorithm tries to find within a tolerance `tau` the most promising (i.e. according to the precision)
+            `beam_size` candidate anchor(s) from a list of proposed anchors. Formally, when the `beam_size=1`,
+            the multi-armed bandit algorithm seeks to find an anchor :math:`A` such that
+            :math:`P(prec(A) \\ge prec(A^\\star) - \\tau) \\ge 1 - \\delta`, where :math:`A^\\star` is the anchor
+            with the highest true precision (which we don't know), :math:`\\tau` is the `tau` parameter,
+            :math:`\\delta` is the `delta` parameter, and :math:`prec(\\cdot)` denotes the precision of an anchor.
+            In other words, in each iteration, the algorithm returns with a probability of at least `1 - delta` an
+            anchor :math:`A` with a precision within an error tolerance of `tau` from the precision of the
+            highest true precision anchor :math:`A^\\star`. A bigger value for `tau` means faster convergence but also
+            looser anchor conditions.
         batch_size
-            Batch size used for sampling.
+            Batch size used for sampling. The Anchor algorithm will query the black-box model in batches of size
+            `batch_size`. A larger `batch_size` gives more confidence in the anchor, again at the expense of
+            computation time since it involves more model prediction calls.
         coverage_samples
             Number of samples used to estimate coverage from during result search.
         beam_size
-            The number of anchors extended at each step of new anchors construction.
+            Number of candidate anchors selected by the multi-armed bandit algorithm in each iteration from a list of
+            proposed anchors. A bigger beam  width can lead to a better overall anchor (i.e. prevents the algorithm
+            of getting stuck in a local maximum) at the expense of more computation time.
         stop_on_first
             If ``True``, the beam search algorithm will return the first anchor that has satisfies the
             probability constraint.
@@ -766,7 +806,15 @@ class AnchorTabular(Explainer, FitMixin):
 
             .. _AnchorTabular examples:
                 https://docs.seldon.io/projects/alibi/en/stable/methods/Anchors.html
+
+        Raises
+        ------
+        :py:class:`alibi.exceptions.NotFittedError`
+            If `fit` has not been called prior to calling `explain`.
         """
+        if not self._fitted:
+            raise NotFittedError(self.meta["name"])
+
         # transform one-hot encodings to labels if ohe == True
         X = ohe_to_ord(X_ohe=X.reshape(1, -1), cat_vars_ohe=self.cat_vars_ohe)[0].reshape(-1) if self.ohe else X
 
@@ -819,7 +867,7 @@ class AnchorTabular(Explainer, FitMixin):
         predicted_label
             Label of the instance to be explained (inferred if not given).
         params
-            Parameters passed to :py:meth:`alibi.explainers.anchor_tabular.AnchorTabular.explain`.
+            Parameters passed to :py:meth:`alibi.explainers.anchors.anchor_tabular.AnchorTabular.explain`.
 
         Return
         ------
@@ -960,11 +1008,11 @@ class AnchorTabular(Explainer, FitMixin):
         except Exception as e:
             msg = f"Predictor failed to be called on {type(x)} of shape {x.shape} and dtype {x.dtype}. " \
                   f"Check that the parameter `feature_names` is correctly specified."
-            raise AlibiPredictorCallException(msg) from e
+            raise PredictorCallError(msg) from e
 
         if not isinstance(prediction, np.ndarray):
             msg = f"Excepted predictor return type to be {np.ndarray} but got {type(prediction)}."
-            raise AlibiPredictorReturnTypeError(msg)
+            raise PredictorReturnTypeError(msg)
 
         if np.argmax(prediction.shape) == 0:
             return predictor
