@@ -19,11 +19,22 @@ err_msg_template = Template((
 ))
 
 
-# Map from specific missing dependency to the name of the optional dependency bucket
+"""Mapping used to ensure correct pip install message is generated if a missing optional dependency is detected. This
+dict is used to control two behaviours:
+
+1. When we import objects from missing dependencies we check that any `ModuleNotFoundError` or `ImportError`
+corresponds to a missing optional dependency by checking the name of the missing dependency is in `ERROR_TYPES`. We
+then map this name to the corresponding optional dependency bucket that will resolve the issue.
+
+2. Some optional dependencies have multiple names such as `torch` and `pytorch`, instead of enforcing a single
+naming convention across the whole code base we instead use `ERROR_TYPES` to capture both cases. This is done right
+before the pip install message is issued as this is the most robust place to capture these differences.
+"""
 ERROR_TYPES = {
     'ray': 'ray',
     'tensorflow': 'tensorflow',
     'torch': 'torch',
+    'pytorch': 'torch',
     'shap': 'shap',
     'numba': 'shap'
 }
@@ -79,16 +90,16 @@ def import_optional(module_name: str, names: Optional[List[str]] = None) -> Any:
 
     Parameters
     ----------
-        module_name
-            The module to import
-        names
-            The names to import from the module. If None, all names are imported.
+    module_name
+        The module to import
+    names
+        The names to import from the module. If None, all names are imported.
 
     Returns
     -------
-        The module or named objects within the modules if names is not None. If the import fails due to a
-        ModuleNotFoundError or ImportError then the requested module or named objects are replaced with instances of
-        the MissingDependency class above.
+    The module or named objects within the modules if names is not None. If the import fails due to a
+    ModuleNotFoundError or ImportError then the requested module or named objects are replaced with instances of
+    the MissingDependency class above.
     """
 
     try:
