@@ -39,6 +39,9 @@ EXCLUDE_NOTEBOOKS = {
 if platform.system() == 'Windows':
    EXCLUDE_NOTEBOOKS.add('protoselect_adult_cifar10.ipynb')  # Exclude <your notebook> on Windows due to the use of wget
    EXCLUDE_NOTEBOOKS.add('similarity_explanations_20ng.ipynb')  # times out, likely due to the EmbeddingModel being slow
+   EXCLUDE_NOTEBOOKS.add('trustscore_mnist.ipynb')  # times out
+if platform.system() == 'Darwin':
+    EXCLUDE_NOTEBOOKS.add('trustscore_mnist.ipynb')  # times out
 EXECUTE_NOTEBOOKS = ALL_NOTEBOOKS - EXCLUDE_NOTEBOOKS
 
 @pytest.mark.timeout(600)
